==> ldap-account-manager_6.7.orig.tar.bz2: ldap-account-manager-6.7/templates/lib/extra/ckeditor/plugins/link/lang/fi.js <==
﻿/*
Copyright (c) 2003-2018, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'fi', {
	acccessKey: 'Pikanäppäin',
	advanced: 'Lisäominaisuudet',
	advisoryContentType: 'Avustava sisällön tyyppi',
	advisoryTitle: 'Avustava otsikko',
	anchor: {
		toolbar: 'Lisää ankkuri/muokkaa ankkuria',
		menu: 'Ankkurin ominaisuudet',
		title: 'Ankkurin ominaisuudet',
		name: 'Nimi',
		errorName: 'Ankkurille on kirjoitettava nimi',
		remove: 'Poista ankkuri'
	},
	anchorId: 'Ankkurin ID:n mukaan',
	anchorName: 'Ankkurin nimen mukaan',
	charset: 'Linkitetty kirjaimisto',
	cssClasses: 'Tyyliluokat',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Sähköpostiosoite',
	emailBody: 'Viesti',
	emailSubject: 'Aihe',
	id: 'Tunniste',
	info: 'Linkin tiedot',
	langCode: 'Kielen suunta',
	langDir: 'Kielen suunta',
	langDirLTR: 'Vasemmalta oikealle (LTR)',
	langDirRTL: 'Oikealta vasemmalle (RTL)',
	menu: 'Muokkaa linkkiä',
	name: 'Nimi',
	noAnchors: '(Ei ankkureita tässä dokumentissa)',
	noEmail: 'Kirjoita sähköpostiosoite',
	noUrl: 'Linkille on kirjoitettava URL',
	other: '<muu>',
	popupDependent: 'Riippuva (Netscape)',
	popupFeatures: 'Popup ikkunan ominaisuudet',
	popupFullScreen: 'Täysi ikkuna (IE)',
	popupLeft: 'Vasemmalta (px)',
	popupLocationBar: 'Osoiterivi',
	popupMenuBar: 'Valikkorivi',
	popupResizable: 'Venytettävä',
	popupScrollBars: 'Vierityspalkit',
	popupStatusBar: 'Tilarivi',
	popupToolbar: 'Vakiopainikkeet',
	popupTop: 'Ylhäältä (px)',
	rel: 'Suhde',
	selectAnchor: 'Valitse ankkuri',
	styles: 'Tyyli',
	tabIndex: 'Tabulaattori indeksi',
	target: 'Kohde',
	targetFrame: '<kehys>',
	targetFrameName: 'Kohdekehyksen nimi',
	targetPopup: '<popup ikkuna>',
	targetPopupName: 'Popup ikkunan nimi',
	title: 'Linkki',
	toAnchor: 'Ankkuri tässä sivussa',
	toEmail: 'Sähköposti',
	toUrl: 'Osoite',
	toolbar: 'Lisää linkki/muokkaa linkkiä',
	type: 'Linkkityyppi',
	unlink: 'Poista linkki',
	upload: 'Lisää tiedosto'
} );

==> ldap-account-manager_8.3.orig.tar.bz2: ldap-account-manager-8.3/templates/lib/extra/ckeditor/plugins/link/lang/fi.js <==
﻿/*
Copyright (c) 2003-2021, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or https://ckeditor.com/legal/ckeditor-oss-license
*/
CKEDITOR.plugins.setLang( 'link', 'fi', {
	acccessKey: 'Pikanäppäin',
	advanced: 'Lisäominaisuudet',
	advisoryContentType: 'Avustava sisällön tyyppi',
	advisoryTitle: 'Avustava otsikko',
	anchor: {
		toolbar: 'Lisää ankkuri/muokkaa ankkuria',
		menu: 'Ankkurin ominaisuudet',
		title: 'Ankkurin ominaisuudet',
		name: 'Nimi',
		errorName: 'Ankkurille on kirjoitettava nimi',
		remove: 'Poista ankkuri'
	},
	anchorId: 'Ankkurin ID:n mukaan',
	anchorName: 'Ankkurin nimen mukaan',
	charset: 'Linkitetty kirjaimisto',
	cssClasses: 'Tyyliluokat',
	download: 'Force Download', // MISSING
	displayText: 'Display Text', // MISSING
	emailAddress: 'Sähköpostiosoite',
	emailBody: 'Viesti',
	emailSubject: 'Aihe',
	id: 'Tunniste',
	info: 'Linkin tiedot',
	langCode: 'Kielen suunta',
	langDir: 'Kielen suunta',
	langDirLTR: 'Vasemmalta oikealle (LTR)',
	langDirRTL: 'Oikealta vasemmalle (RTL)',
	menu: 'Muokkaa linkkiä',
	name: 'Nimi',
	noAnchors: '(Ei ankkureita tässä dokumentissa)',
	noEmail: 'Kirjoita sähköpostiosoite',
	noUrl: 'Linkille on kirjoitettava URL',
	noTel: 'Please type the phone number', // MISSING
	other: '<muu>',
	phoneNumber: 'Phone number', // MISSING
	popupDependent: 'Riippuva (Netscape)',
	popupFeatures: 'Popup ikkunan ominaisuudet',
	popupFullScreen: 'Täysi ikkuna (IE)',
	popupLeft: 'Vasemmalta (px)',
	popupLocationBar: 'Osoiterivi',
	popupMenuBar: 'Valikkorivi',
	popupResizable: 'Venytettävä',
	popupScrollBars: 'Vierityspalkit',
	popupStatusBar: 'Tilarivi',
	popupToolbar: 'Vakiopainikkeet',
	popupTop: 'Ylhäältä (px)',
	rel: 'Suhde',
	selectAnchor: 'Valitse ankkuri',
	styles: 'Tyyli',
	tabIndex: 'Tabulaattori indeksi',
	target: 'Kohde',
	targetFrame: '<kehys>',
	targetFrameName: 'Kohdekehyksen nimi',
	targetPopup: '<popup ikkuna>',
	targetPopupName: 'Popup ikkunan nimi',
	title: 'Linkki',
	toAnchor: 'Ankkuri tässä sivussa',
	toEmail: 'Sähköposti',
	toUrl: 'Osoite',
	toPhone: 'Phone', // MISSING
	toolbar: 'Lisää linkki/muokkaa linkkiä',
	type: 'Linkkityyppi',
	unlink: 'Poista linkki',
	upload: 'Lisää tiedosto'
} );
